# Changelog

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](http://semver.org/).

Unless otherwise stated, these changes have been implemented by [ljmc][ljmc].

[ljmc]: https://gitlab.com/ljmc

## Changes

### v0.0.1 (2022-12-18)

* First release
* Pushed to `pypi`
